@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for VineLinux 6.0's 2.6.35 kernel.
+# This is a kernel build script for VineLinux 5.2's 2.6.27 kernel.
 #
 
 die () {
@@ -10,34 +10,34 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.35-21vl6.src.rpm ]
+if [ ! -r kernel-2.6.27-76vl5.src.rpm ]
 then
-    wget http://updates.vinelinux.org/Vine-6.0/updates/SRPMS/kernel-2.6.35-21vl6.src.rpm || die "Can't download source package."
+    wget http://updates.vinelinux.org/Vine-5.2/updates/SRPMS/kernel-2.6.27-76vl5.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.35-21vl6.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.35-21vl6.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.27-76vl5.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.27-76vl5.src.rpm || die "Can't install source package."
 
-cd /root/rpm/SOURCES/ || die "Can't chdir to /root/rpm/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20120401.tar.gz ]
+cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
+if [ ! -r ccs-patch-1.8.3-20120610.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20120401.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120401.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20120610.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120610.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
-cp -p /root/rpm/SPECS/kernel-vl.spec . || die "Can't copy spec file."
+cp -p /usr/src/vine/SPECS/kernel-2.6-vl.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-vl.spec
-+++ kernel-vl.spec
-@@ -28,7 +28,7 @@
- %define patchlevel 13
+--- kernel-2.6-vl.spec
++++ kernel-2.6-vl.spec
+@@ -27,7 +27,7 @@
+ %define patchlevel 62
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
--%define release 21%{?_dist_release}
-+%define release 21%{?_dist_release}_tomoyo_1.8.3p6
+-%define release 76%{?_dist_release}
++%define release 76%{?_dist_release}_tomoyo_1.8.3p7
  
  %define make_target bzImage
  %define hdrarch %_target_cpu
-@@ -120,6 +120,9 @@
+@@ -121,6 +121,9 @@
  # to versions below the minimum
  #
  
@@ -47,27 +47,27 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -152,7 +155,7 @@
+@@ -153,7 +156,7 @@
  #
- %define kernel_prereq  fileutils, module-init-tools >= 3.6, initscripts >= 8.80, mkinitrd >= 6.0.93, linux-firmware >= 20110601-1
+ %define kernel_prereq  fileutils, module-init-tools >= 3.6, initscripts >= 8.80, mkinitrd >= 5.1.19.6, kernel-firmware >= %{version}
  
 -Name: kernel
 +Name: ccs-kernel
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -651,6 +654,10 @@
+@@ -848,6 +851,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20120401.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.35-vine-linux-6.0.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20120610.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.27-vine-linux-5.2.diff
 +
  cp %{SOURCE10} Documentation/
  
  # put Vine logo
-@@ -669,6 +676,9 @@
+@@ -866,6 +873,9 @@
  for i in *.config
  do 
  	mv $i .config 
@@ -78,7 +78,7 @@ patch << "EOF" || die "Can't patch spec file."
  	echo "# $Arch" > configs/$i
  	cat .config >> configs/$i 
 EOF
-mv kernel-vl.spec ccs-kernel.spec || die "Can't rename spec file."
+mv kernel-2.6-vl.spec ccs-kernel.spec || die "Can't rename spec file."
 echo ""
 echo ""
 echo ""
